@@ -37,7 +37,9 @@ __all__ = (
     "RelativePositionType",
     "ScheduleEntryTypeType",
     "TypeType",
+    "MediaTailorServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -59,6 +61,7 @@ PlaybackModeType = Literal["LINEAR", "LOOP"]
 RelativePositionType = Literal["AFTER_PROGRAM", "BEFORE_PROGRAM"]
 ScheduleEntryTypeType = Literal["FILLER_SLATE", "PROGRAM"]
 TypeType = Literal["DASH", "HLS"]
+MediaTailorServiceName = Literal["mediatailor"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -90,6 +93,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -212,6 +216,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -360,6 +365,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "get_channel_schedule",
     "list_alerts",
