@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AccessTypeType,
     ChannelStateType,
@@ -142,29 +144,28 @@ __all__ = (
 AccessConfigurationTypeDef = TypedDict(
     "AccessConfigurationTypeDef",
     {
-        "AccessType": AccessTypeType,
-        "SecretsManagerAccessTokenConfiguration": "SecretsManagerAccessTokenConfigurationTypeDef",
+        "AccessType": NotRequired[AccessTypeType],
+        "SecretsManagerAccessTokenConfiguration": NotRequired[
+            "SecretsManagerAccessTokenConfigurationTypeDef"
+        ],
     },
-    total=False,
 )
 
 AdBreakTypeDef = TypedDict(
     "AdBreakTypeDef",
     {
-        "MessageType": Literal["SPLICE_INSERT"],
-        "OffsetMillis": int,
-        "Slate": "SlateSourceTypeDef",
-        "SpliceInsertMessage": "SpliceInsertMessageTypeDef",
+        "MessageType": NotRequired[Literal["SPLICE_INSERT"]],
+        "OffsetMillis": NotRequired[int],
+        "Slate": NotRequired["SlateSourceTypeDef"],
+        "SpliceInsertMessage": NotRequired["SpliceInsertMessageTypeDef"],
     },
-    total=False,
 )
 
 AdMarkerPassthroughTypeDef = TypedDict(
     "AdMarkerPassthroughTypeDef",
     {
-        "Enabled": bool,
+        "Enabled": NotRequired[bool],
     },
-    total=False,
 )
 
 AlertTypeDef = TypedDict(
@@ -189,55 +190,41 @@ AvailMatchingCriteriaTypeDef = TypedDict(
 AvailSuppressionTypeDef = TypedDict(
     "AvailSuppressionTypeDef",
     {
-        "Mode": ModeType,
-        "Value": str,
+        "Mode": NotRequired[ModeType],
+        "Value": NotRequired[str],
     },
-    total=False,
 )
 
 BumperTypeDef = TypedDict(
     "BumperTypeDef",
     {
-        "EndUrl": str,
-        "StartUrl": str,
+        "EndUrl": NotRequired[str],
+        "StartUrl": NotRequired[str],
     },
-    total=False,
 )
 
 CdnConfigurationTypeDef = TypedDict(
     "CdnConfigurationTypeDef",
     {
-        "AdSegmentUrlPrefix": str,
-        "ContentSegmentUrlPrefix": str,
+        "AdSegmentUrlPrefix": NotRequired[str],
+        "ContentSegmentUrlPrefix": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredChannelTypeDef = TypedDict(
-    "_RequiredChannelTypeDef",
+ChannelTypeDef = TypedDict(
+    "ChannelTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
         "ChannelState": str,
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
+        "CreationTime": NotRequired[datetime],
+        "FillerSlate": NotRequired["SlateSourceTypeDef"],
+        "LastModifiedTime": NotRequired[datetime],
+        "Tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalChannelTypeDef = TypedDict(
-    "_OptionalChannelTypeDef",
-    {
-        "CreationTime": datetime,
-        "FillerSlate": "SlateSourceTypeDef",
-        "LastModifiedTime": datetime,
-        "Tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
-    pass
-
 
 ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef = TypedDict(
     "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
@@ -256,29 +243,16 @@ ConfigureLogsForPlaybackConfigurationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateChannelRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateChannelRequestRequestTypeDef",
+CreateChannelRequestRequestTypeDef = TypedDict(
+    "CreateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Outputs": Sequence["RequestOutputItemTypeDef"],
         "PlaybackMode": PlaybackModeType,
+        "FillerSlate": NotRequired["SlateSourceTypeDef"],
+        "Tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateChannelRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateChannelRequestRequestTypeDef",
-    {
-        "FillerSlate": "SlateSourceTypeDef",
-        "Tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateChannelRequestRequestTypeDef(
-    _RequiredCreateChannelRequestRequestTypeDef, _OptionalCreateChannelRequestRequestTypeDef
-):
-    pass
-
 
 CreateChannelResponseTypeDef = TypedDict(
     "CreateChannelResponseTypeDef",
@@ -296,30 +270,16 @@ CreateChannelResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
-    "_RequiredCreatePrefetchScheduleRequestRequestTypeDef",
+CreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
+    "CreatePrefetchScheduleRequestRequestTypeDef",
     {
         "Consumption": "PrefetchConsumptionTypeDef",
         "Name": str,
         "PlaybackConfigurationName": str,
         "Retrieval": "PrefetchRetrievalTypeDef",
+        "StreamId": NotRequired[str],
     },
 )
-_OptionalCreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
-    "_OptionalCreatePrefetchScheduleRequestRequestTypeDef",
-    {
-        "StreamId": str,
-    },
-    total=False,
-)
-
-
-class CreatePrefetchScheduleRequestRequestTypeDef(
-    _RequiredCreatePrefetchScheduleRequestRequestTypeDef,
-    _OptionalCreatePrefetchScheduleRequestRequestTypeDef,
-):
-    pass
-
 
 CreatePrefetchScheduleResponseTypeDef = TypedDict(
     "CreatePrefetchScheduleResponseTypeDef",
@@ -334,30 +294,17 @@ CreatePrefetchScheduleResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateProgramRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateProgramRequestRequestTypeDef",
+CreateProgramRequestRequestTypeDef = TypedDict(
+    "CreateProgramRequestRequestTypeDef",
     {
         "ChannelName": str,
         "ProgramName": str,
         "ScheduleConfiguration": "ScheduleConfigurationTypeDef",
         "SourceLocationName": str,
         "VodSourceName": str,
+        "AdBreaks": NotRequired[Sequence["AdBreakTypeDef"]],
     },
 )
-_OptionalCreateProgramRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateProgramRequestRequestTypeDef",
-    {
-        "AdBreaks": Sequence["AdBreakTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateProgramRequestRequestTypeDef(
-    _RequiredCreateProgramRequestRequestTypeDef, _OptionalCreateProgramRequestRequestTypeDef
-):
-    pass
-
 
 CreateProgramResponseTypeDef = TypedDict(
     "CreateProgramResponseTypeDef",
@@ -374,31 +321,21 @@ CreateProgramResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateSourceLocationRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateSourceLocationRequestRequestTypeDef",
+CreateSourceLocationRequestRequestTypeDef = TypedDict(
+    "CreateSourceLocationRequestRequestTypeDef",
     {
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
+        "AccessConfiguration": NotRequired["AccessConfigurationTypeDef"],
+        "DefaultSegmentDeliveryConfiguration": NotRequired[
+            "DefaultSegmentDeliveryConfigurationTypeDef"
+        ],
+        "SegmentDeliveryConfigurations": NotRequired[
+            Sequence["SegmentDeliveryConfigurationTypeDef"]
+        ],
+        "Tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateSourceLocationRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateSourceLocationRequestRequestTypeDef",
-    {
-        "AccessConfiguration": "AccessConfigurationTypeDef",
-        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
-        "SegmentDeliveryConfigurations": Sequence["SegmentDeliveryConfigurationTypeDef"],
-        "Tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateSourceLocationRequestRequestTypeDef(
-    _RequiredCreateSourceLocationRequestRequestTypeDef,
-    _OptionalCreateSourceLocationRequestRequestTypeDef,
-):
-    pass
-
 
 CreateSourceLocationResponseTypeDef = TypedDict(
     "CreateSourceLocationResponseTypeDef",
@@ -416,28 +353,15 @@ CreateSourceLocationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateVodSourceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateVodSourceRequestRequestTypeDef",
+CreateVodSourceRequestRequestTypeDef = TypedDict(
+    "CreateVodSourceRequestRequestTypeDef",
     {
         "HttpPackageConfigurations": Sequence["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
         "VodSourceName": str,
+        "Tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateVodSourceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateVodSourceRequestRequestTypeDef",
-    {
-        "Tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateVodSourceRequestRequestTypeDef(
-    _RequiredCreateVodSourceRequestRequestTypeDef, _OptionalCreateVodSourceRequestRequestTypeDef
-):
-    pass
-
 
 CreateVodSourceResponseTypeDef = TypedDict(
     "CreateVodSourceResponseTypeDef",
@@ -456,39 +380,35 @@ CreateVodSourceResponseTypeDef = TypedDict(
 DashConfigurationForPutTypeDef = TypedDict(
     "DashConfigurationForPutTypeDef",
     {
-        "MpdLocation": str,
-        "OriginManifestType": OriginManifestTypeType,
+        "MpdLocation": NotRequired[str],
+        "OriginManifestType": NotRequired[OriginManifestTypeType],
     },
-    total=False,
 )
 
 DashConfigurationTypeDef = TypedDict(
     "DashConfigurationTypeDef",
     {
-        "ManifestEndpointPrefix": str,
-        "MpdLocation": str,
-        "OriginManifestType": OriginManifestTypeType,
+        "ManifestEndpointPrefix": NotRequired[str],
+        "MpdLocation": NotRequired[str],
+        "OriginManifestType": NotRequired[OriginManifestTypeType],
     },
-    total=False,
 )
 
 DashPlaylistSettingsTypeDef = TypedDict(
     "DashPlaylistSettingsTypeDef",
     {
-        "ManifestWindowSeconds": int,
-        "MinBufferTimeSeconds": int,
-        "MinUpdatePeriodSeconds": int,
-        "SuggestedPresentationDelaySeconds": int,
+        "ManifestWindowSeconds": NotRequired[int],
+        "MinBufferTimeSeconds": NotRequired[int],
+        "MinUpdatePeriodSeconds": NotRequired[int],
+        "SuggestedPresentationDelaySeconds": NotRequired[int],
     },
-    total=False,
 )
 
 DefaultSegmentDeliveryConfigurationTypeDef = TypedDict(
     "DefaultSegmentDeliveryConfigurationTypeDef",
     {
-        "BaseUrl": str,
+        "BaseUrl": NotRequired[str],
     },
-    total=False,
 )
 
 DeleteChannelPolicyRequestRequestTypeDef = TypedDict(
@@ -649,29 +569,15 @@ GetChannelPolicyResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetChannelScheduleRequestRequestTypeDef = TypedDict(
-    "_RequiredGetChannelScheduleRequestRequestTypeDef",
+GetChannelScheduleRequestRequestTypeDef = TypedDict(
+    "GetChannelScheduleRequestRequestTypeDef",
     {
         "ChannelName": str,
+        "DurationMinutes": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalGetChannelScheduleRequestRequestTypeDef = TypedDict(
-    "_OptionalGetChannelScheduleRequestRequestTypeDef",
-    {
-        "DurationMinutes": str,
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class GetChannelScheduleRequestRequestTypeDef(
-    _RequiredGetChannelScheduleRequestRequestTypeDef,
-    _OptionalGetChannelScheduleRequestRequestTypeDef,
-):
-    pass
-
 
 GetChannelScheduleResponseTypeDef = TypedDict(
     "GetChannelScheduleResponseTypeDef",
@@ -739,17 +645,15 @@ GetPrefetchScheduleResponseTypeDef = TypedDict(
 HlsConfigurationTypeDef = TypedDict(
     "HlsConfigurationTypeDef",
     {
-        "ManifestEndpointPrefix": str,
+        "ManifestEndpointPrefix": NotRequired[str],
     },
-    total=False,
 )
 
 HlsPlaylistSettingsTypeDef = TypedDict(
     "HlsPlaylistSettingsTypeDef",
     {
-        "ManifestWindowSeconds": int,
+        "ManifestWindowSeconds": NotRequired[int],
     },
-    total=False,
 )
 
 HttpConfigurationTypeDef = TypedDict(
@@ -768,27 +672,14 @@ HttpPackageConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredListAlertsRequestRequestTypeDef = TypedDict(
-    "_RequiredListAlertsRequestRequestTypeDef",
+ListAlertsRequestRequestTypeDef = TypedDict(
+    "ListAlertsRequestRequestTypeDef",
     {
         "ResourceArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListAlertsRequestRequestTypeDef = TypedDict(
-    "_OptionalListAlertsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListAlertsRequestRequestTypeDef(
-    _RequiredListAlertsRequestRequestTypeDef, _OptionalListAlertsRequestRequestTypeDef
-):
-    pass
-
 
 ListAlertsResponseTypeDef = TypedDict(
     "ListAlertsResponseTypeDef",
@@ -802,10 +693,9 @@ ListAlertsResponseTypeDef = TypedDict(
 ListChannelsRequestRequestTypeDef = TypedDict(
     "ListChannelsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListChannelsResponseTypeDef = TypedDict(
@@ -820,10 +710,9 @@ ListChannelsResponseTypeDef = TypedDict(
 ListPlaybackConfigurationsRequestRequestTypeDef = TypedDict(
     "ListPlaybackConfigurationsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListPlaybackConfigurationsResponseTypeDef = TypedDict(
@@ -835,29 +724,15 @@ ListPlaybackConfigurationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
-    "_RequiredListPrefetchSchedulesRequestRequestTypeDef",
+ListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
+    "ListPrefetchSchedulesRequestRequestTypeDef",
     {
         "PlaybackConfigurationName": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "StreamId": NotRequired[str],
     },
 )
-_OptionalListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
-    "_OptionalListPrefetchSchedulesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-        "StreamId": str,
-    },
-    total=False,
-)
-
-
-class ListPrefetchSchedulesRequestRequestTypeDef(
-    _RequiredListPrefetchSchedulesRequestRequestTypeDef,
-    _OptionalListPrefetchSchedulesRequestRequestTypeDef,
-):
-    pass
-
 
 ListPrefetchSchedulesResponseTypeDef = TypedDict(
     "ListPrefetchSchedulesResponseTypeDef",
@@ -871,10 +746,9 @@ ListPrefetchSchedulesResponseTypeDef = TypedDict(
 ListSourceLocationsRequestRequestTypeDef = TypedDict(
     "ListSourceLocationsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListSourceLocationsResponseTypeDef = TypedDict(
@@ -901,27 +775,14 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListVodSourcesRequestRequestTypeDef = TypedDict(
-    "_RequiredListVodSourcesRequestRequestTypeDef",
+ListVodSourcesRequestRequestTypeDef = TypedDict(
+    "ListVodSourcesRequestRequestTypeDef",
     {
         "SourceLocationName": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListVodSourcesRequestRequestTypeDef = TypedDict(
-    "_OptionalListVodSourcesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListVodSourcesRequestRequestTypeDef(
-    _RequiredListVodSourcesRequestRequestTypeDef, _OptionalListVodSourcesRequestRequestTypeDef
-):
-    pass
-
 
 ListVodSourcesResponseTypeDef = TypedDict(
     "ListVodSourcesResponseTypeDef",
@@ -935,10 +796,9 @@ ListVodSourcesResponseTypeDef = TypedDict(
 LivePreRollConfigurationTypeDef = TypedDict(
     "LivePreRollConfigurationTypeDef",
     {
-        "AdDecisionServerUrl": str,
-        "MaxDurationSeconds": int,
+        "AdDecisionServerUrl": NotRequired[str],
+        "MaxDurationSeconds": NotRequired[int],
     },
-    total=False,
 )
 
 LogConfigurationTypeDef = TypedDict(
@@ -951,113 +811,73 @@ LogConfigurationTypeDef = TypedDict(
 ManifestProcessingRulesTypeDef = TypedDict(
     "ManifestProcessingRulesTypeDef",
     {
-        "AdMarkerPassthrough": "AdMarkerPassthroughTypeDef",
+        "AdMarkerPassthrough": NotRequired["AdMarkerPassthroughTypeDef"],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PlaybackConfigurationTypeDef = TypedDict(
     "PlaybackConfigurationTypeDef",
     {
-        "AdDecisionServerUrl": str,
-        "AvailSuppression": "AvailSuppressionTypeDef",
-        "Bumper": "BumperTypeDef",
-        "CdnConfiguration": "CdnConfigurationTypeDef",
-        "ConfigurationAliases": Dict[str, Dict[str, str]],
-        "DashConfiguration": "DashConfigurationTypeDef",
-        "HlsConfiguration": "HlsConfigurationTypeDef",
-        "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
-        "LogConfiguration": "LogConfigurationTypeDef",
-        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
-        "Name": str,
-        "PersonalizationThresholdSeconds": int,
-        "PlaybackConfigurationArn": str,
-        "PlaybackEndpointPrefix": str,
-        "SessionInitializationEndpointPrefix": str,
-        "SlateAdUrl": str,
-        "Tags": Dict[str, str],
-        "TranscodeProfileName": str,
-        "VideoContentSourceUrl": str,
+        "AdDecisionServerUrl": NotRequired[str],
+        "AvailSuppression": NotRequired["AvailSuppressionTypeDef"],
+        "Bumper": NotRequired["BumperTypeDef"],
+        "CdnConfiguration": NotRequired["CdnConfigurationTypeDef"],
+        "ConfigurationAliases": NotRequired[Dict[str, Dict[str, str]]],
+        "DashConfiguration": NotRequired["DashConfigurationTypeDef"],
+        "HlsConfiguration": NotRequired["HlsConfigurationTypeDef"],
+        "LivePreRollConfiguration": NotRequired["LivePreRollConfigurationTypeDef"],
+        "LogConfiguration": NotRequired["LogConfigurationTypeDef"],
+        "ManifestProcessingRules": NotRequired["ManifestProcessingRulesTypeDef"],
+        "Name": NotRequired[str],
+        "PersonalizationThresholdSeconds": NotRequired[int],
+        "PlaybackConfigurationArn": NotRequired[str],
+        "PlaybackEndpointPrefix": NotRequired[str],
+        "SessionInitializationEndpointPrefix": NotRequired[str],
+        "SlateAdUrl": NotRequired[str],
+        "Tags": NotRequired[Dict[str, str]],
+        "TranscodeProfileName": NotRequired[str],
+        "VideoContentSourceUrl": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredPrefetchConsumptionTypeDef = TypedDict(
-    "_RequiredPrefetchConsumptionTypeDef",
+PrefetchConsumptionTypeDef = TypedDict(
+    "PrefetchConsumptionTypeDef",
     {
         "EndTime": Union[datetime, str],
+        "AvailMatchingCriteria": NotRequired[Sequence["AvailMatchingCriteriaTypeDef"]],
+        "StartTime": NotRequired[Union[datetime, str]],
     },
 )
-_OptionalPrefetchConsumptionTypeDef = TypedDict(
-    "_OptionalPrefetchConsumptionTypeDef",
-    {
-        "AvailMatchingCriteria": Sequence["AvailMatchingCriteriaTypeDef"],
-        "StartTime": Union[datetime, str],
-    },
-    total=False,
-)
 
-
-class PrefetchConsumptionTypeDef(
-    _RequiredPrefetchConsumptionTypeDef, _OptionalPrefetchConsumptionTypeDef
-):
-    pass
-
-
-_RequiredPrefetchRetrievalTypeDef = TypedDict(
-    "_RequiredPrefetchRetrievalTypeDef",
+PrefetchRetrievalTypeDef = TypedDict(
+    "PrefetchRetrievalTypeDef",
     {
         "EndTime": Union[datetime, str],
+        "DynamicVariables": NotRequired[Mapping[str, str]],
+        "StartTime": NotRequired[Union[datetime, str]],
     },
 )
-_OptionalPrefetchRetrievalTypeDef = TypedDict(
-    "_OptionalPrefetchRetrievalTypeDef",
-    {
-        "DynamicVariables": Mapping[str, str],
-        "StartTime": Union[datetime, str],
-    },
-    total=False,
-)
 
-
-class PrefetchRetrievalTypeDef(
-    _RequiredPrefetchRetrievalTypeDef, _OptionalPrefetchRetrievalTypeDef
-):
-    pass
-
-
-_RequiredPrefetchScheduleTypeDef = TypedDict(
-    "_RequiredPrefetchScheduleTypeDef",
+PrefetchScheduleTypeDef = TypedDict(
+    "PrefetchScheduleTypeDef",
     {
         "Arn": str,
         "Consumption": "PrefetchConsumptionTypeDef",
         "Name": str,
         "PlaybackConfigurationName": str,
         "Retrieval": "PrefetchRetrievalTypeDef",
+        "StreamId": NotRequired[str],
     },
 )
-_OptionalPrefetchScheduleTypeDef = TypedDict(
-    "_OptionalPrefetchScheduleTypeDef",
-    {
-        "StreamId": str,
-    },
-    total=False,
-)
-
-
-class PrefetchScheduleTypeDef(_RequiredPrefetchScheduleTypeDef, _OptionalPrefetchScheduleTypeDef):
-    pass
-
 
 PutChannelPolicyRequestRequestTypeDef = TypedDict(
     "PutChannelPolicyRequestRequestTypeDef",
@@ -1070,22 +890,21 @@ PutChannelPolicyRequestRequestTypeDef = TypedDict(
 PutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
     "PutPlaybackConfigurationRequestRequestTypeDef",
     {
-        "AdDecisionServerUrl": str,
-        "AvailSuppression": "AvailSuppressionTypeDef",
-        "Bumper": "BumperTypeDef",
-        "CdnConfiguration": "CdnConfigurationTypeDef",
-        "ConfigurationAliases": Mapping[str, Mapping[str, str]],
-        "DashConfiguration": "DashConfigurationForPutTypeDef",
-        "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
-        "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
-        "Name": str,
-        "PersonalizationThresholdSeconds": int,
-        "SlateAdUrl": str,
-        "Tags": Mapping[str, str],
-        "TranscodeProfileName": str,
-        "VideoContentSourceUrl": str,
+        "AdDecisionServerUrl": NotRequired[str],
+        "AvailSuppression": NotRequired["AvailSuppressionTypeDef"],
+        "Bumper": NotRequired["BumperTypeDef"],
+        "CdnConfiguration": NotRequired["CdnConfigurationTypeDef"],
+        "ConfigurationAliases": NotRequired[Mapping[str, Mapping[str, str]]],
+        "DashConfiguration": NotRequired["DashConfigurationForPutTypeDef"],
+        "LivePreRollConfiguration": NotRequired["LivePreRollConfigurationTypeDef"],
+        "ManifestProcessingRules": NotRequired["ManifestProcessingRulesTypeDef"],
+        "Name": NotRequired[str],
+        "PersonalizationThresholdSeconds": NotRequired[int],
+        "SlateAdUrl": NotRequired[str],
+        "Tags": NotRequired[Mapping[str, str]],
+        "TranscodeProfileName": NotRequired[str],
+        "VideoContentSourceUrl": NotRequired[str],
     },
-    total=False,
 )
 
 PutPlaybackConfigurationResponseTypeDef = TypedDict(
@@ -1114,28 +933,15 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredRequestOutputItemTypeDef = TypedDict(
-    "_RequiredRequestOutputItemTypeDef",
+RequestOutputItemTypeDef = TypedDict(
+    "RequestOutputItemTypeDef",
     {
         "ManifestName": str,
         "SourceGroup": str,
+        "DashPlaylistSettings": NotRequired["DashPlaylistSettingsTypeDef"],
+        "HlsPlaylistSettings": NotRequired["HlsPlaylistSettingsTypeDef"],
     },
 )
-_OptionalRequestOutputItemTypeDef = TypedDict(
-    "_OptionalRequestOutputItemTypeDef",
-    {
-        "DashPlaylistSettings": "DashPlaylistSettingsTypeDef",
-        "HlsPlaylistSettings": "HlsPlaylistSettingsTypeDef",
-    },
-    total=False,
-)
-
-
-class RequestOutputItemTypeDef(
-    _RequiredRequestOutputItemTypeDef, _OptionalRequestOutputItemTypeDef
-):
-    pass
-
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -1148,39 +954,25 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredResponseOutputItemTypeDef = TypedDict(
-    "_RequiredResponseOutputItemTypeDef",
+ResponseOutputItemTypeDef = TypedDict(
+    "ResponseOutputItemTypeDef",
     {
         "ManifestName": str,
         "PlaybackUrl": str,
         "SourceGroup": str,
+        "DashPlaylistSettings": NotRequired["DashPlaylistSettingsTypeDef"],
+        "HlsPlaylistSettings": NotRequired["HlsPlaylistSettingsTypeDef"],
     },
 )
-_OptionalResponseOutputItemTypeDef = TypedDict(
-    "_OptionalResponseOutputItemTypeDef",
-    {
-        "DashPlaylistSettings": "DashPlaylistSettingsTypeDef",
-        "HlsPlaylistSettings": "HlsPlaylistSettingsTypeDef",
-    },
-    total=False,
-)
-
-
-class ResponseOutputItemTypeDef(
-    _RequiredResponseOutputItemTypeDef, _OptionalResponseOutputItemTypeDef
-):
-    pass
-
 
 ScheduleAdBreakTypeDef = TypedDict(
     "ScheduleAdBreakTypeDef",
     {
-        "ApproximateDurationSeconds": int,
-        "ApproximateStartTime": datetime,
-        "SourceLocationName": str,
-        "VodSourceName": str,
+        "ApproximateDurationSeconds": NotRequired[int],
+        "ApproximateStartTime": NotRequired[datetime],
+        "SourceLocationName": NotRequired[str],
+        "VodSourceName": NotRequired[str],
     },
-    total=False,
 )
 
 ScheduleConfigurationTypeDef = TypedDict(
@@ -1190,95 +982,71 @@ ScheduleConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredScheduleEntryTypeDef = TypedDict(
-    "_RequiredScheduleEntryTypeDef",
+ScheduleEntryTypeDef = TypedDict(
+    "ScheduleEntryTypeDef",
     {
         "Arn": str,
         "ChannelName": str,
         "ProgramName": str,
         "SourceLocationName": str,
         "VodSourceName": str,
+        "ApproximateDurationSeconds": NotRequired[int],
+        "ApproximateStartTime": NotRequired[datetime],
+        "ScheduleAdBreaks": NotRequired[List["ScheduleAdBreakTypeDef"]],
+        "ScheduleEntryType": NotRequired[ScheduleEntryTypeType],
     },
 )
-_OptionalScheduleEntryTypeDef = TypedDict(
-    "_OptionalScheduleEntryTypeDef",
-    {
-        "ApproximateDurationSeconds": int,
-        "ApproximateStartTime": datetime,
-        "ScheduleAdBreaks": List["ScheduleAdBreakTypeDef"],
-        "ScheduleEntryType": ScheduleEntryTypeType,
-    },
-    total=False,
-)
-
-
-class ScheduleEntryTypeDef(_RequiredScheduleEntryTypeDef, _OptionalScheduleEntryTypeDef):
-    pass
-
 
 SecretsManagerAccessTokenConfigurationTypeDef = TypedDict(
     "SecretsManagerAccessTokenConfigurationTypeDef",
     {
-        "HeaderName": str,
-        "SecretArn": str,
-        "SecretStringKey": str,
+        "HeaderName": NotRequired[str],
+        "SecretArn": NotRequired[str],
+        "SecretStringKey": NotRequired[str],
     },
-    total=False,
 )
 
 SegmentDeliveryConfigurationTypeDef = TypedDict(
     "SegmentDeliveryConfigurationTypeDef",
     {
-        "BaseUrl": str,
-        "Name": str,
+        "BaseUrl": NotRequired[str],
+        "Name": NotRequired[str],
     },
-    total=False,
 )
 
 SlateSourceTypeDef = TypedDict(
     "SlateSourceTypeDef",
     {
-        "SourceLocationName": str,
-        "VodSourceName": str,
+        "SourceLocationName": NotRequired[str],
+        "VodSourceName": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredSourceLocationTypeDef = TypedDict(
-    "_RequiredSourceLocationTypeDef",
+SourceLocationTypeDef = TypedDict(
+    "SourceLocationTypeDef",
     {
         "Arn": str,
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
+        "AccessConfiguration": NotRequired["AccessConfigurationTypeDef"],
+        "CreationTime": NotRequired[datetime],
+        "DefaultSegmentDeliveryConfiguration": NotRequired[
+            "DefaultSegmentDeliveryConfigurationTypeDef"
+        ],
+        "LastModifiedTime": NotRequired[datetime],
+        "SegmentDeliveryConfigurations": NotRequired[List["SegmentDeliveryConfigurationTypeDef"]],
+        "Tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalSourceLocationTypeDef = TypedDict(
-    "_OptionalSourceLocationTypeDef",
-    {
-        "AccessConfiguration": "AccessConfigurationTypeDef",
-        "CreationTime": datetime,
-        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
-        "LastModifiedTime": datetime,
-        "SegmentDeliveryConfigurations": List["SegmentDeliveryConfigurationTypeDef"],
-        "Tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class SourceLocationTypeDef(_RequiredSourceLocationTypeDef, _OptionalSourceLocationTypeDef):
-    pass
-
 
 SpliceInsertMessageTypeDef = TypedDict(
     "SpliceInsertMessageTypeDef",
     {
-        "AvailNum": int,
-        "AvailsExpected": int,
-        "SpliceEventId": int,
-        "UniqueProgramId": int,
+        "AvailNum": NotRequired[int],
+        "AvailsExpected": NotRequired[int],
+        "SpliceEventId": NotRequired[int],
+        "UniqueProgramId": NotRequired[int],
     },
-    total=False,
 )
 
 StartChannelRequestRequestTypeDef = TypedDict(
@@ -1303,26 +1071,15 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredTransitionTypeDef = TypedDict(
-    "_RequiredTransitionTypeDef",
+TransitionTypeDef = TypedDict(
+    "TransitionTypeDef",
     {
         "RelativePosition": RelativePositionType,
         "Type": str,
+        "RelativeProgram": NotRequired[str],
+        "ScheduledStartTimeMillis": NotRequired[int],
     },
 )
-_OptionalTransitionTypeDef = TypedDict(
-    "_OptionalTransitionTypeDef",
-    {
-        "RelativeProgram": str,
-        "ScheduledStartTimeMillis": int,
-    },
-    total=False,
-)
-
-
-class TransitionTypeDef(_RequiredTransitionTypeDef, _OptionalTransitionTypeDef):
-    pass
-
 
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
@@ -1332,27 +1089,14 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateChannelRequestRequestTypeDef",
+UpdateChannelRequestRequestTypeDef = TypedDict(
+    "UpdateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Outputs": Sequence["RequestOutputItemTypeDef"],
+        "FillerSlate": NotRequired["SlateSourceTypeDef"],
     },
 )
-_OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateChannelRequestRequestTypeDef",
-    {
-        "FillerSlate": "SlateSourceTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateChannelRequestRequestTypeDef(
-    _RequiredUpdateChannelRequestRequestTypeDef, _OptionalUpdateChannelRequestRequestTypeDef
-):
-    pass
-
 
 UpdateChannelResponseTypeDef = TypedDict(
     "UpdateChannelResponseTypeDef",
@@ -1370,30 +1114,20 @@ UpdateChannelResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateSourceLocationRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateSourceLocationRequestRequestTypeDef",
+UpdateSourceLocationRequestRequestTypeDef = TypedDict(
+    "UpdateSourceLocationRequestRequestTypeDef",
     {
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "SourceLocationName": str,
+        "AccessConfiguration": NotRequired["AccessConfigurationTypeDef"],
+        "DefaultSegmentDeliveryConfiguration": NotRequired[
+            "DefaultSegmentDeliveryConfigurationTypeDef"
+        ],
+        "SegmentDeliveryConfigurations": NotRequired[
+            Sequence["SegmentDeliveryConfigurationTypeDef"]
+        ],
     },
 )
-_OptionalUpdateSourceLocationRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateSourceLocationRequestRequestTypeDef",
-    {
-        "AccessConfiguration": "AccessConfigurationTypeDef",
-        "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
-        "SegmentDeliveryConfigurations": Sequence["SegmentDeliveryConfigurationTypeDef"],
-    },
-    total=False,
-)
-
-
-class UpdateSourceLocationRequestRequestTypeDef(
-    _RequiredUpdateSourceLocationRequestRequestTypeDef,
-    _OptionalUpdateSourceLocationRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateSourceLocationResponseTypeDef = TypedDict(
     "UpdateSourceLocationResponseTypeDef",
@@ -1434,25 +1168,15 @@ UpdateVodSourceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredVodSourceTypeDef = TypedDict(
-    "_RequiredVodSourceTypeDef",
+VodSourceTypeDef = TypedDict(
+    "VodSourceTypeDef",
     {
         "Arn": str,
         "HttpPackageConfigurations": List["HttpPackageConfigurationTypeDef"],
         "SourceLocationName": str,
         "VodSourceName": str,
+        "CreationTime": NotRequired[datetime],
+        "LastModifiedTime": NotRequired[datetime],
+        "Tags": NotRequired[Dict[str, str]],
     },
 )
-_OptionalVodSourceTypeDef = TypedDict(
-    "_OptionalVodSourceTypeDef",
-    {
-        "CreationTime": datetime,
-        "LastModifiedTime": datetime,
-        "Tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class VodSourceTypeDef(_RequiredVodSourceTypeDef, _OptionalVodSourceTypeDef):
-    pass
